class RFID:
  def __init__(self,uart):
    self.uart = uart
    self.reco = b'\xA0\x03\x82\x00\xDB\x00\x00'
    self.readMsg = b'\xA0\x06\x80\x00\x01\x02\x01\xD6\x00\x00' 
    self.stopReadData = b'\xA0\x03\x50\x00\x0D\x00\x00'
    self.buzzerOn = b'\xA0\x04\xB0\x00\x01\xAB\x00\x00'
    self.buzzerOff = b'\xA0\x04\xB0\x00\x00\xAC\x00\x00'
    self.rereco = b'\xA0\x03\xFC\x00\x61\x00\x00'
    self.reList = b'\xA0\x03\x65\x00\xF8\x00\x00'
    self.writeData = bytearray(b'\xA0\x09\x81\x00\x00\x01\x02\x01\x00\x00\xD2\x00\x00')
#    stopRead = self.stopAutoRead()
    
  def getMsg(self):
    try:
      while True:
        if(uart.any() == True):
          sleep(100)
          data = uart.readline()
          break
      return data
    except:
      return 'False'
  
  def check(self,data,head,state,site=3):
    i = 0
    for i in range(0,len(data)):
      if(data[i] == head and data[site] == state):
        return i
      else:
        i = i+1
    return -1

  def read(self):
    for n in range(0,3):
      self.uart.write(self.readMsg)
      data = self.getMsg()
      i = self.check(data,0xE0,0x08,1)
      if i >= 0:
        return data[i+7],data[i+8]
    return -1,-1
      
  def stopAutoRead(self):
    self.uart.write(self.stopReadData)
    data = self.getMsg()
    i = self.check(data,0xE4,0x00)
    if(i >= 0):
      return True
    else:
      return False
      
  def write(self,num1,num2):
    check = 0xD2 - num1 - num2
    self.writeData[8] = num1
    self.writeData[9] = num2
    self.writeData[10] = check
    self.uart.write(self.writeData)
    data = self.getMsg()
    i = self.check(data,0xE0,0x00,4)
    if(i >= 0):
      return True
    else:
      return False
    
  def buzzerOpen(self):
    self.uart.write(self.buzzerOn)
    data = self.getMsg()
    i = self.check(data,0xE4,0x00)
    if(i >= 0):
      return True
    else:
      return False
  
  def buzzerClose(self):
    self.uart.write(self.buzzerOff)
    data = self.getMsg()
    i = self.check(data,0xE4,0x00)
    if(i >= 0):
      return True
    else:
      return False
   
  def reset(self):
    self.uart.write(self.reList)
    data = self.getMsg()
    i = self.check(data,0xE4,0x00)
    self.stopAutoRead()
    if(i >= 0):
      return True
    else:
      return False
  
  def recognize(self):
    self.uart.write(self.reco)
    data = self.getMsg()
    i = self.check(data,0xE0,0x00)
    card = ''
    if(i >= 0):
      #for n in range(5,17):
      #  card += str((data[i+n]))+' '
      #  card = card.strip()
      return data[5:17]
    return None
  
